
#include "qmlapplicationviewer.h"
#include <QApplication>
#include <QtDeclarative>
#include <QDeclarativeEngine>
#include <QDeclarativeView>
#include <QDeclarativeContext>
#include <QUrl>
#include "src/network.h"
#include "src/parse.h"
#include "src/gps.h"
#include "src/yandexlocator.h"
#include "src/gensettings.h"
#include "src/countdistance.h"

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    QmlApplicationViewer viewer;

    Network net;
    Parse par;
    Gps gp;
    yandexLocator loc;
    GenSettings settings;
    CountDistance distance;

    /* Connect C++ Classes with QML */
    viewer.rootContext()->setContextProperty("myObject", &net);
    viewer.rootContext()->setContextProperty("cppEngine", &par);
    viewer.rootContext()->setContextProperty("obj", &gp);
    viewer.rootContext()->setContextProperty("locator", &loc);
    viewer.rootContext()->setContextProperty("applicationDirPath", QApplication::applicationDirPath());
    viewer.rootContext()->setContextProperty("qtSettings", &settings);

    QObject::connect(&gp,SIGNAL(posUpdatedGps(double,double)), &distance, SLOT(getPosition(double,double)));
    QObject::connect(&loc,SIGNAL(posUpdatedLocator(double,double)), &distance, SLOT(getPosition(double,double)));
    QObject::connect(&par,SIGNAL(dangerous(double*, double*, unsigned int)), &distance, SLOT(startDangerous(double*, double*, unsigned int)));
    QObject::connect(&net,SIGNAL(startParse(QString)), &par, SLOT(parseCSVFile(QString)));
    QObject::connect((QObject*)viewer.engine(), SIGNAL(quit()), &app, SLOT(quit()));
    viewer.rootContext()->setContextProperty("distance", &distance);
    viewer.setMainQmlFile(QLatin1String(UIPREFIX"main.qml"));
    qDebug() << "Qt uiprefix: " << UIPREFIX;

    QObject *mf = viewer.rootObject();
    mf->setProperty("uiprefix", QString(UIPREFIX));

    viewer.showExpanded();

    return app.exec();
}
