/*
 * Firepoint
 * A fire monitoring app
 * http://launchpad.net/firepoint
 *
 * Copyright 2011, 2012 Inessa Sofronova, Artem Kalinin, Artem Timonin, Alex Troshkov
 * <atroshko@cs.karelia.ru>
 *
 * Firepoint is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

#include "countdistance.h"
#include "parse.h"

CountDistance::CountDistance(QObject *parent) :
    QObject(parent)
{
    flag_points = 0;
    checkDistance = 200;
    lat = -300;
    lon = -300;
    gpsUpdateCount = 3;
}

/* Get current user coordinates */
void CountDistance::getPosition(double lat_pos, double lon_pos)
{
    /* If fire points' coordinates are available, start searching nearby fire */
    if (flag_points == 1){
        if (gpsUpdateCount > 2){
            findMin(lat_pos, lon_pos);
            gpsUpdateCount = 0;
        }
        gpsUpdateCount++;
        return;
    }
}

/* Get fire points from module Parse */
void CountDistance::startDangerous(double *lt1, double *ln1, unsigned int length1)
{
    ln = lt1;
    lt = ln1;
    length = length1;
    flag_points = 1;

}

/* Count distance to fire in kilomeneters */
void CountDistance::countDistanceToFire(double lat1, double lon1, double lat2, double lon2)
{
    double dist; //distance to fire

    double cl1, cl2, sl1, sl2, cdelta, sdelta, delta;
    double x,y;
    double ad;

    /* Variables for sending to 'dangerous' */
    double fireLat = lat1;
    double fireLon = lon1;
    double userLat = lat2;
    double userLon = lon2;

    /* Preparation of the variables */
    lat1 = lat1*PI/180;
    lat2 = lat2*PI/180;
    lon1 = lon1*PI/180;
    lon2 = lon2*PI/180;
    cl1 = qCos(lat1);
    cl2 =  qCos(lat2);
    sl1 = qSin(lat1);
    sl2 = qSin(lat2);
    delta = lon2 - lon1;
    cdelta = qCos(delta);
    sdelta = qSin(delta);
    y = qSqrt(qPow(cl2*sdelta,2)+qPow(cl1*sl2-sl1*cl2*cdelta,2));
    x = sl1*sl2+cl1*cl2*cdelta;
    ad = qAtan2(y,x);

    /* Count distance */
    dist = ad*RAD;

    qDebug()<< "Distance: " << dist;

    /* Save new nearby fire point */
    if ((lat != lat1) || (lon != lon1))
    {
        checkDistance = 200;
        lat = lat1;
        lon = lon1;
    }

    /* If user goes to fire, warn him */
    if (dist < checkDistance/2)
    {
        checkDistance = dist;
        emit pushReport();
        emit dangerSend(fireLat, fireLon, userLat, userLon, dist); //send signal to Map module
    }
    return;
}

/* Enumeration values of fires latitude and longitude
 * 
 * Find nearest fire
 */
void CountDistance::findMin(double la, double lo)
{
    if (length <= 0 )
    {
        qDebug() << "length of points array <= 0";
        return;
    }
    double min; // the shortest distance to fire
    double res; // average value of distance to fire

    /* Count distance for first fire in array */
    min = (la - lt[0])*(la - lt[0]) + (lo - ln[0])*(lo - ln[0]);
    unsigned int i;
    unsigned int k = 0;

    /* Iterates through the array and count distance */
    for (i = 0; i < length; i++)
    {
        res = (la - lt[i])*(la - lt[i])+(lo - ln[i])*(lo - ln[i]);

        /* Сompare with the current shortest distance */
        if (res < min)
        {
            min = res;
            k = i;
        }
    }

    /* Count distance to nearby fire in kilometers */
    countDistanceToFire(lt[k], ln[k], la, lo );
}
