/*
 * Firepoint
 * A fire monitoring app
 * http://launchpad.net/firepoint
 *
 * Copyright 2011, 2012 Inessa Sofronova, Artem Kalinin, Artem Timonin, Alex Troshkov
 * <atroshko@cs.karelia.ru>
 *
 * Firepoint is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

#include "gensettings.h"

/* Constructor */
GenSettings::GenSettings()
{
    agreement = "no";
    location_provider = "gps";
    countryCode = "6";
    mapType = "Normal";
    lat = "52,50568190";
    lon= "13,32320270";
    countryName = "Europe";
    home = QDir::homePath() + "/.frp/";
    qDebug() << "home: " << home;
}

/* Load settings from file */
void GenSettings::loadSettings()
{
    //qDebug() << home;
    if (QFile::exists(home + "settings.conf"))
    {
        QSettings settings(home + "settings.conf", QSettings::NativeFormat);

        if (settings.status() == QSettings::FormatError)
            qDebug() << "A format error occurred (e.g. loading a malformed INI file";

        location_provider = settings.value("provider", "").toString();
        countryCode = settings.value("countryCode", "").toString();
        mapType = settings.value("map", "").toString();
        lat = settings.value("lat", "").toString();
        lon = settings.value("lon", "").toString();
        countryName = settings.value("countryName", "").toString();
        agreement = settings.value("agreement", "").toString();
     }
    else
    {
        return;
    }
}

/* Save provider, country code and map look */
void GenSettings::saveSettings(QString provider, QString country, QString map)
{
    QSettings settings(home + "settings.conf", QSettings::NativeFormat);

    settings.setValue("provider", provider);
    settings.setValue("countryCode", country);
    settings.setValue("map", map);

    if (settings.status() == QSettings::AccessError)
        qDebug() << "An access error occurred (e.g. trying to write to a read-only file)";

}

/* Save latitude and longitude */
void GenSettings::saveSettingsCoordinates(QString lat, QString lon)
{
    QSettings settings(home + "settings.conf", QSettings::NativeFormat);

    settings.setValue("lat", lat);
    settings.setValue("lon", lon);

    if (settings.status() == QSettings::AccessError)
        qDebug() << "An access error occurred (e.g. trying to write to a read-only file)";
}

/* Save area name */
void GenSettings::saveSettingsCountryName(QString countryName)
{
    QSettings settings(home + "settings.conf", QSettings::NativeFormat);
    settings.setValue("countryName", countryName);

    if (settings.status() == QSettings::AccessError)
        qDebug() << "An access error occurred (e.g. trying to write to a read-only file)";

}

/* Save agreement */
void GenSettings::saveAgreement(QString agreement)
{
    QSettings settings(home + "settings.conf", QSettings::NativeFormat);
    settings.setValue("agreement", agreement);

    if (settings.status() == QSettings::AccessError)
        qDebug() << "An access error occurred (e.g. trying to write to a read-only file)";

}

/* Getter for countryCode */
QString GenSettings::getCountryCode()
{
    return countryCode;
}

/* Getter for location_provider */
QString GenSettings::getProvider()
{
    return location_provider;
}

/* Getter for mapType*/
QString GenSettings::getMapType()
{
    return mapType;
}

/* Getter for latitude */
QString GenSettings::getLatitude()
{
    return lat;
}

/* Getter for longitude */
QString GenSettings::getLongitude()
{
    return lon;
}

/* Getter for area name */
QString GenSettings::getCountryName()
{
    return countryName;
}

/* Getter for agreement */
QString GenSettings::getAgreement()
{
    return agreement;
}
