/*
 * Firepoint
 * A fire monitoring app
 * http://launchpad.net/firepoint
 *
 * Copyright 2011, 2012 Inessa Sofronova, Artem Kalinin, Artem Timonin, Alex Troshkov
 * <atroshko@cs.karelia.ru>
 *
 * Firepoint is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

#include "gps.h"

Gps::Gps()
{
    lon = 0;
    lat = 0;
}

/* Start timer for GPS */
void Gps::startGps()
{
    m_geoSource = QGeoPositionInfoSource::createDefaultSource(this);

    if (m_geoSource)
    {
        connect(m_geoSource, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(positionUpdated(QGeoPositionInfo)));
        m_geoSource->setUpdateInterval(5000);
        m_geoSource->startUpdates();
    }
}

/* When we close map we need stop to GPS updates */
void Gps::stopGps()
{
    if (m_geoSource)
        m_geoSource->stopUpdates();
}

/* Sending signal to Map */
void Gps::positionUpdated(QGeoPositionInfo info)
{
    lat = info.coordinate().latitude();
    lon = info.coordinate().longitude();
    emit posUpdatedGps (lat ,lon);
}

/* Getter for latitude */
double Gps::getGpsLat()
{
    return lat;
}

/* Getter for longitude */
double Gps::getGpsLon()
{
    return lon;
}
