/*
 * Firepoint
 * A fire monitoring app
 * http://launchpad.net/firepoint
 *
 * Copyright 2011, 2012 Inessa Sofronova, Artem Kalinin, Artem Timonin, Alex Troshkov
 * <atroshko@cs.karelia.ru>
 *
 * Firepoint is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

#include "parse.h"

Parse::Parse()
{
}

/* Parsing XML file fire points' data */
void Parse::parseFile(QString fileName)
{
    /* Opening XML file */
    QDomDocument doc(fileName);
    QFile file(fileName);
    if (!file.open(QIODevice::ReadOnly))
    {
        qDebug() << "Open file error";
        emit errorParse("There was an error while opening XML-file");
        return;
    }

    /* Set file's data into XML tree */
    if (!doc.setContent(&file))
    {
        file.close();
        file.remove();
        qDebug() << "Read file error";
        emit errorParse("Read file error");
        return;
    }

    /* Parsing XML tree */
    docElem = doc.documentElement();

    strCoords = docElem.elementsByTagName("coordinates");

    length = strCoords.length();
    if (length == 0)
    {
        qDebug() << "There are no firepoints";
        emit errorParse("There are no firepoints");
        return;
     }

    /* Lengths of arrays lt и ln, containing fire points' coordinates */
    ln = new double[length];
    lt = new double[length];

    unsigned int i;
    double lon;
    double lat;
    QString curPoint;

    /* Traversal of the XML tree, picking out "coordinates" and then sending coordinates to Map module */
    for(i = 0; i < length; i++)
    {
        curPoint=strCoords.item(i).toElement().text();

        /* Getting coordinates of the current fire point */
        coords = curPoint.split(",", QString::SkipEmptyParts);
        lat = coords[0].toDouble();
        lon = coords[1].toDouble();

        /* Adding fire point to coordinates' arrays */
        ln[i] = lon;
        lt[i] = lat;

        /* Sending coordinates to Map module */
        emit posUpdated(lat, lon);
    }

    /* Closing XML file */
    file.close();

    /* Send arrays with fire point to module countdistance */
    emit dangerous(lt, ln, length);

    /* Updating map in Map module */
    emit mapUpdate();

    return;
}

/* Parsing CSV file fire points' data */
void Parse::parseCSVFile(QString fileName)
{
    QFile file(fileName);
    if (!file.open (QIODevice::ReadOnly))
    {
        emit errorParse("There was an error while opening CSV-file");
        return;
    }
    QTextStream stream (&file);
    QString line;
    line = stream.readLine();
    QStringList l;
    QVector<double> lon;
    QVector<double> lat;
    double longitude;
    double latitude;
    bool ok = true;
    while(!stream.atEnd())
    {
         line = stream.readLine();
         l = line.split(",", QString::SkipEmptyParts);
         if (l.size() < 2)
         {
             emit errorParse("There was an error while parsing CSV-file");
             return;
         }
         ok = true;
         longitude = l.takeFirst().toDouble(&ok);
         if (ok)
             lon << longitude;
         else
         {
             emit errorParse("There was an error while parsing CSV-file");
             return;
         }
         ok = true;
         latitude = l.takeFirst().toDouble(&ok);
         if (ok)
             lat << latitude;
         else
         {
             emit errorParse("There was an error while parsing CSV-file");
             return;
         }
         l.clear();
    }

    file.close();

    length = lat.size();
    ln = new double[length];
    lt = new double[length];
    unsigned int i;
    for (i = 0; i < length; i++)
    {
        lt[i] = lat[i];
        ln[i] = lon[i];
        emit posUpdated(lt[i], ln[i]);
    }

    /* Send arrays with fire point to module countdistance */
    emit dangerous(lt, ln, length);

    /* Updating map in Map module */
    emit mapUpdate();

    return;
}
