/*
 * Firepoint
 * A fire monitoring app
 * http://launchpad.net/firepoint
 *
 * Copyright 2011, 2012 Inessa Sofronova, Artem Kalinin, Artem Timonin, Alex Troshkov
 * <atroshko@cs.karelia.ru>
 *
 * Firepoint is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

#include "yandexlocator.h"

/* Constructor */
yandexLocator::yandexLocator()
{
    lat = 0;
    lon = 0;
}

/* Start update cordinates */
void yandexLocator::startLocator()
{
    timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(createRequest()));
    timer->start(5000);
}

/* Create and send reques to Yandex.locator */
void yandexLocator::createRequest()
{
    QSystemNetworkInfo networkInfo;
    QString code;
    QString xml;

    /* Create xml request */
    xml = "xml=<ya_lbs_request><common><version>1.0</version><api_key>AFuBw04BAAAAMTvVXAIAPh1FQcViqX_YMyHSr38laE_zr6YAAAAAAAAAAACv_CRUIU-VJsqPpO-ArbvLPAIs4Q==</api_key></common>";

    xml +="<gsm_cells><cell><countrycode>";
    code = networkInfo.currentMobileCountryCode();

    xml += code + "</countrycode><operatorid>";
    code = networkInfo.currentMobileNetworkCode();

    xml += code + "</operatorid><cellid>";
    code = Check(networkInfo.cellId());

    xml += code + "</cellid><lac>";
    code = Check(networkInfo.locationAreaCode());

    xml += code + "</lac></cell></gsm_cells>";

    xml += "<wifi_networks><network><mac>";
    code =  networkInfo.macAddress(QSystemNetworkInfo::WlanMode);

    xml += code + "</mac><signal_strength>";

    code = Check(networkInfo.networkSignalStrength(QSystemNetworkInfo::WlanMode));
    xml += code + "</signal_strength></network></wifi_networks><ip><address_v4>";

    QList<QHostAddress> addresses = QNetworkInterface::allAddresses();
    QString protocol = "";
    QString ip;
    code = "";

    /* Current IP */
    foreach ( const QHostAddress & a, addresses )
    {
        protocol = a.protocol();
        if (protocol == "IPv4")
        {
            ip = a.toString();
            if (ip != "127.0.0.1")
                code = ip;
        }
    }

    xml += code + "</address_v4></ip>";
    xml+="</ya_lbs_request>";

    /* transform created xml request to ByteArray */
    QByteArray byte_request;
    byte_request.append(xml);

    /* Create http headers */
    request.setUrl(QUrl("http://api.lbs.yandex.net/geolocation"));
    request.setRawHeader("Host", "api.lbs.yandex.net");
    request.setRawHeader("Accept-Encoding", "identity");
    request.setRawHeader("Content-type", "application/x-www-form-urlencoded");

    /* Post request */
    reply = manager.post(request, byte_request);
    connect(reply, SIGNAL(readyRead()), this, SLOT(parseAnswer()));
}

/* Read and parse answer from Yandex.locator */
void yandexLocator::parseAnswer()
{
    /* Read answer */
    QByteArray data = reply->readAll();
    QDomDocument doc;
    QDomNodeList xml_lat;
    QDomNodeList xml_lon;

    /* Parse answer */
    if(doc.setContent(data))
    {
        QDomElement docElem = doc.documentElement(); // root xml element

        if (docElem.firstChildElement().text().isEmpty()) //check for right xml file
            qDebug() << "empty file";
        else
        {
            /* find latitude and longitude in xml */
            xml_lat = docElem.elementsByTagName("latitude");
            xml_lon = docElem.elementsByTagName("longitude");
            if (!xml_lat.isEmpty() && !xml_lon.isEmpty())
            {
                bool ok = true;
                double latitude;
                double longitude;
                latitude = xml_lat.item(0).toElement().text().toDouble(&ok);
                if (ok)
                    lat = latitude;
                ok = true;
                longitude = xml_lon.item(0).toElement().text().toDouble(&ok);
                if (ok)
                    lon = longitude;
                /* Send update coordinates signal to UI */
                emit posUpdatedLocator(lat, lon);
            }
            else
                qDebug() << "Coordinates fields are empty";
        }
    }
    else
    {
        qDebug() << "parse problem" << endl;
        emit locatorError("Locator Parse problem");
    }
    return;
}

/* Simple check for return value */
QString yandexLocator::Check(int k)
{
    if (k == -1)
        return "";
    else
        return QString::number(k);
}

/* Getter for latitude */
double yandexLocator::getLocatorLat()
{
    return lat;
}

/* Getter for longitude */
double yandexLocator::getLocatorLon()
{
    return lon;
}

/* When close map, we need stop yandexLocator updates */
void yandexLocator::stopLocator()
{
    if (timer)
        timer->stop();
}
