/* 
 * Firepoint
 * A fire monitoring app
 * http://launchpad.net/firepoint
 *
 * Copyright 2011, 2012 Inessa Sofronova, Artem Kalinin, Artem Timonin, Alex Troshkov
 * <atroshko@cs.karelia.ru>
 *
 * Firepoint is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */

import QtQuick 1.1
//import com.nokia.meego 1.0
import com.nokia.symbian 1.1
import Qt.labs.components 1.1
import "GlobalVariables.js" as GlobalVariables


Page {
    function deleteFile(){
        if(myObject.deleteFile() === 2)//Call method of Network module)
            playbanner.start()
        if(myObject.deleteFile() === 1)//Call method of Network module)
            playbanner.start()
    }

    property string mapProvider: ""
    property string mapType: ""
    property string countrySettings: ""

    /* Call genSettings Module and save settings */
    function saveSettings(){
        if (gps.checked == true)
            mapProvider = "gps"

        if (geo.checked == true)
            mapProvider = "geo"
        countrySettings = singleSelection.selectedIndex

        if (mapType == "")
            mapType = "0"
        qtSettings.saveSettings(mapProvider, countrySettings, mapType)
        qtSettings.saveSettingsCountryName(regionChooser.text=singleSelection.model.get(singleSelection.selectedIndex).name)
        pageStack.pop()
    }
    
    property string location: "" //need to load settings
    property string countryCode: ""

    id: settings
    orientationLock: 1

    tools: commonTools

    /* On start page */
    Component.onCompleted: {

        qtSettings.loadSettings()
        /* Считываем переменные из класса */
        mapProvider = qtSettings.getProvider()
        countrySettings = qtSettings.getCountryCode()
        mapType = qtSettings.getMapType()

        /* Устанавливаем RadioButton провайдера в нужное состояние */
        if(mapProvider == "geo"){
            geo.checked = true
            gps.checked = false
        }
        if(mapProvider == "gps"){
            geo.checked = false
            gps.checked = true
        }
        singleSelection.selectedIndex = countrySettings
        regionChooser.text=singleSelection.model.get(countrySettings).name
    }

    Image {
        source: "img/background.png"
    }

    /* Header Item */
    Item {
        id: headerRect
        anchors.top:settings.top; anchors.left: settings.left; anchors.right: settings.right
        width: settings.width ; height: 78

        Image {
            width: parent.width
            height: 78
            source: "img/header.png"
            fillMode: Image.Tile
        }

        Text {
            id: titleText
            color: "white"
            x: parent.x + 20
            anchors.verticalCenter: headerRect.verticalCenter

            font.pixelSize: 26
            text: qsTr("Preferences")
            font.family: 'Nokia Pure Text'
        }
    }

    /* Radio buttons for settings provider */
    CheckableGroup { id: group }
    Column {
        y: 100
        spacing: 30
        anchors.fill: parent
        anchors.topMargin: 100
       // anchors.horizontalCenter: parent.horizontalCenter
        Text {
            color: 'white'
            font.pixelSize: 26
            text: qsTr("Choose location provider:")
            font.family: 'Nokia Pure Text'
            x: parent.x + 20
        }

            RadioButton {
                text: "                   "
                id: gps
                checked: true
                platformExclusiveGroup: group
                x: parent.x + 50
                Text{
                    x:60
                    text:"GPS"
                    font.pixelSize:26
                    color:"white"
                    font.family: 'Nokia Pure Text'
                }
            }

            RadioButton {
                id: geo
                checked: true
                text: "                                     "
                platformExclusiveGroup: group
                x: parent.x + 50
                Text {
                    x:60
                    text:"Yandex.Locator"
                    font.pixelSize: 26
                    color:"white"
                    font.family: 'Nokia Pure Text'

                }

            }

        Text {
            color: 'white'
            font.pixelSize: 26
            text: qsTr("Choose region to download:")
            font.family: 'Nokia Pure Text'
            x: parent.x + 20
        }

        /* Call choose region menu */
        Button {
            id: regionChooser
            text: qsTr("Click to choose region")
            onClicked: singleSelection.open()
            anchors.horizontalCenter : parent.horizontalCenter
        }

        // Create a selection dialog with a title and list elements to choose from.
         SelectionDialog {
             id: singleSelection
             titleText: qsTr("Region to download")
             selectedIndex: 0

             model: ListModel {
                 ListElement { name: "Global" }
                 ListElement { name: "Alaska" }
                 ListElement { name: "Australia and New Zealand" }
                 ListElement { name: "Canada" }
                 ListElement { name: "Central America" }
                 ListElement { name: "Europe" }
                 ListElement { name: "Northern and Central Africa" }
                 ListElement { name: "Russia and Asia" }
                 ListElement { name: "South America" }
                 ListElement { name: "South Asia" }
                 ListElement { name: "SouthEast Asia" }
                 ListElement { name: "Southern Africa" }
                 ListElement { name: "USA contiguous and Hawaii" }
             }
             onAccepted: {
                 regionChooser.text=singleSelection.model.get(singleSelection.selectedIndex).name
                 myObject.deleteFile()
               }
        }

        Text {
            color: 'white'
            font.pixelSize: 20
            text: qsTr("It helps you not to download extra fire points.\nSo, this config reduces traffic consumption")
            font.family: 'Nokia Pure Text'
            x: parent.x + 20
        }

        Text {
            color: 'white'
            font.pixelSize: 26
            text: qsTr("Clear points cache manually:")
            font.family: 'Nokia Pure Text'
            x: parent.x + 20
        }

        /* Clear file with fire points */
        Button {
            id: cacheCleaner
            text: qsTr("Clear points cache")
            anchors.horizontalCenter : parent.horizontalCenter
            onClicked: {
                deleteFile()
            }
        }

        Text {
            color: 'white'
            font.pixelSize: 20
            text: qsTr("You are able to clear points cache manually. Old\ncache is desirable to be removed")
            font.family: 'Nokia Pure Text'
            x: parent.x + 20
        }


        Text{
            id:clearPoints
            color: 'white'
            font.pixelSize: 20
            text: qsTr("All points have been removed")
            font.family: 'Nokia Pure Text'
            x: parent.x + 170
            opacity: 0

        }

    }

	NumberAnimation {
		id: playbanner
		running: false
		target: clearPoints;
		property: "opacity";
		to: 1.0;
		duration: 300
	}

    /* Main bottom menu */
     ToolBarLayout {
        ToolButton {
            iconSource: "toolbar-back"
            onClicked: pageStack.pop() //back to mainMenu without saving
        }
        
        ToolButton {
            iconSource: "toolbar-settings";
            onClicked: saveSettings() //saveSettings and back to mainMenu
        }
        
        id: commonTools
        visible: true

      }
}
